@@ -24,6 +24,7 @@
 
 #include <atk/atk.h>
 #include <droute/droute.h>
+#include "bridge.h"
 
 #include "spi-dbus.h"
 #include "object.h"
@@ -249,8 +250,8 @@ static DRouteProperty properties[] = {
 void
 spi_initialize_selection (DRoutePath * path)
 {
-  droute_path_add_interface (path,
-                             ATSPI_DBUS_INTERFACE_SELECTION,
-                             spi_org_a11y_atspi_Selection,
-                             methods, properties);
+  spi_atk_add_interface (path,
+                         ATSPI_DBUS_INTERFACE_SELECTION,
+                         spi_org_a11y_atspi_Selection,
+                         methods, properties);
 };
